@@ -10,7 +10,7 @@ import numpy as np
 from tqdm import tqdm
 
 
-def froc_point(gt_ann, pred_ann, score_thres, use_iou, iou_thres):
+def froc_point(gt_ann, pr_ann, score_thres, use_iou, iou_thres):
     gt = load_json_from_file(gt_ann)
     pr = load_json_from_file(pred_ann)
 
@@ -31,7 +31,9 @@ def froc_point(gt_ann, pred_ann, score_thres, use_iou, iou_thres):
 
 
 def generate_froc_curve(
-    gt_ann, pred_ann, use_iou, iou_thres, n_sample_points, plot_title, plot_output_path
+    gt_ann, pr_ann, use_iou=False,
+    iou_thres=.5, n_sample_points=50,
+    plot_title='FROC curve', plot_output_path='froc.png'
 ):
     lls_accuracy = {}
     nlls_per_image = {}
